avatars
=======

The Avatar Python client has three components:

- The API, which lists all the calls that you can make
- The different models, which are used for validation by the `pydantic <https://pydantic-docs.helpmanual.io/>`_ package
- The client that issues the requests to the API

Table of contents
-----------------

.. toctree::
   :maxdepth: 1

   Installation <installation>
   Tutorial <tutorial>
   User Guide <user_guide>
   API reference <api_reference>
   Changelog <changelog>

Our main docs are at https://docs.octopize.io/
